@@ -2,9 +2,7 @@
 sdf_schema.tbl_pyspark <- function(
     x,
     expand_nested_cols = NULL,
-    expand_struct_cols = NULL
-    ) {
-
+    expand_struct_cols = NULL) {
   check_arg_supported(expand_nested_cols)
   check_arg_supported(expand_struct_cols)
 
