@@ -8,8 +8,8 @@
 #' @returns It returns messages to the console with the status of starting, and
 #' stopping the local Spark Connect service.
 #' @export
-spark_connect_service_start <- function(version = "3.5",
-                                        scala_version = "2.12",
+spark_connect_service_start <- function(version = "4.0",
+                                        scala_version = "2.13",
                                         include_args = TRUE,
                                         ...) {
   get_version <- spark_install_find(version = version)
@@ -21,6 +21,16 @@ spark_connect_service_start <- function(version = "3.5",
   if (!include_args) {
     args <- ""
   }
+  cli_div(theme = cli_colors())
+  cli_text("{.header Starting {.emph Spark Connect} locally ...}")
+  java_version <- try(
+    system2("java", "-version", stdout = TRUE, stderr = TRUE),
+    silent = TRUE
+  )
+  if (!inherits(java_version, "try-error")) {
+    out_java <- setNames(java_version, rep("", times = length(java_version)))
+    cli_bullets(out_java)
+  }
   prs <- process$new(
     command = cmd,
     args = args,
@@ -28,8 +38,6 @@ spark_connect_service_start <- function(version = "3.5",
     stderr = "|",
     stdin = "|"
   )
-  cli_div(theme = cli_colors())
-  cli_text("{.header Starting {.emph Spark Connect} locally ...}")
   output <- prs$read_all_output()
   cli_bullets(c(" " = "{.info {output}}"))
   error <- prs$read_all_error()
@@ -42,7 +50,7 @@ spark_connect_service_start <- function(version = "3.5",
 
 #' @rdname spark_connect_service_start
 #' @export
-spark_connect_service_stop <- function(version = "3.5",
+spark_connect_service_stop <- function(version = "4.0",
                                        ...) {
   get_version <- spark_install_find(version = version)
   cmd <- path(get_version$sparkVersionDir, "sbin", "stop-connect-server.sh")
